/*===============================================================================================*/
/*===============================================================================================*/
/*This SAS file generates a panel of firms, using RAIS*/
/*We gather information on 2-digit industry, average wages, */
/*skill composition, total employment.*/
/*the 2-digit industry of a given firm is constructed using SAS file CNPJ_CNAE9406.sas*/
/*In that file, we select the most frequent reported industry at the firm level (8 digit)*/
/*between 1994 and 2006. */
/*In this panel, We do not allow firms to change industry over time.*/
/*===============================================================================================*/
/*===============================================================================================*/


/*================*/
/*Library Names*/
/*================*/

libname rais "/home/dix-carneiro/Data/Data_Brazil/RAIS" ;
libname painel "/home/dix-carneiro/Panel_RAIS" ;



%macro firms ;

%do ano = 1995 %to 2006 ;

%let ano2 = %substr(&ano.,3,2) ;

data firms_&ano2. (keep = 	CNPJ 
                            pis
					  	    cat_educ1-cat_educ4 
                           	hourly_wage
					       	hours
						   	ones 
                            rem_media&ano2.)	;
	set rais.brasil&ano2. ;


	pis = pis&ano2. ;

/*	CNPJ at the 8 digit level. We only have firms.*/
	CNPJ = substr(CNPJ&ano2.,1,8) ;


	if length(compress(CNPJ)) = 8 ;


/*	Only count those employees who are employed in december of the year*/
	if rem_dez&ano2. > 0 & rem_dez&ano2. ~= . ;


	cat_educ1 = 0 ;
	cat_educ2 = 0 ;
	cat_educ3 = 0 ;
	cat_educ4 = 0 ;


	if grau_instr&ano2. = 1 or grau_instr&ano2. = 2 or grau_instr&ano2. = 3 then cat_educ1 = 1 ;
	if grau_instr&ano2. = 4 or grau_instr&ano2. = 5 or grau_instr&ano2. = 6 then cat_educ2 = 1 ;
	if grau_instr&ano2. = 7                                                 then cat_educ3 = 1 ;
	if grau_instr&ano2. = 8 or grau_instr&ano2. = 9                         then cat_educ4 = 1 ;
	
/*Use average earnings of workers*/
	if rem_media&ano2. = 0 or rem_media&ano2. = . then rem_media&ano2. = rem_dez&ano2. ;

	if horas_contr&ano2. ~= . & horas_contr&ano2. > 0 
	then hourly_wage = rem_media&ano2. / (4.35*horas_contr&ano2.) ;

	hours = horas_contr&ano2. ;

	ones = 1 ;

run ;



/*Keep one worker per firm (CNPJ)*/
/*Keep the observation with highest earnings*/
proc sort data = firms_&ano2. ; by cnpj pis descending rem_media&ano2. ; run ;

/*Create enumeration variable by CNPJ & PIS*/
data firms_&ano2. ;
  set firms_&ano2. ;
  count + 1 ;
  by cnpj pis ;
  if first.cnpj or first.pis then count = 1 ;
run;

/*Keep only the first observation by CNPJ & PIS*/
data firms_&ano2. (drop = count pis) ;
	set firms_&ano2. ;	
	if count = 1 ;
run ;






proc sort data = firms_&ano2. ; by cnpj ; run ;


proc means noprint data = firms_&ano2. sumsize = max ;
	by cnpj ;
	var cat_educ1 cat_educ2 cat_educ3 cat_educ4 ones hourly_wage ;
	weight hours ;
	output out = cat_educ_&ano2. (keep = cnpj cat_educ1 cat_educ2 cat_educ3 cat_educ4 
                                  avg_hourly_wage q1_hourly_wage median_hourly_wage q3_hourly_wage 
                                  total_hours)
	mean(cat_educ1 cat_educ2 cat_educ3 cat_educ4 hourly_wage) = cat_educ1 cat_educ2 cat_educ3 
                                                                cat_educ4 avg_hourly_wage
	Q1(hourly_wage) = q1_hourly_wage
	median(hourly_wage) = median_hourly_wage
	Q3(hourly_wage) = q3_hourly_wage
	sum(ones) = total_hours ;
run ;


proc means noprint data = firms_&ano2. sumsize = max ;
	by cnpj ;
	var ones ;
	output out = total_emp_&ano2. (keep = cnpj total_emp)
	sum(ones) = total_emp ;
run ;


data firms_&ano2. (keep = CNPJ year cat_educ1-cat_educ4 avg_hourly_wage median_hourly_wage q1_hourly_wage 
                          q3_hourly_wage total_hours total_emp);
	merge cat_educ_&ano2. (in = a) total_emp_&ano2. ;
	by cnpj ;
	if a ;
	if length(compress(CNPJ)) = 8 ;
	year = &ano ;
run ;


%end ;

%mend ;

%firms ;

data cnpj_cnae9406 (keep = cnpj CNAE) ;
	set painel.cnpj_cnae9406 ;
	cnpj = cnpj8 ;
run ;
	
proc sort data = cnpj_cnae9406 ; by cnpj ; run ;

data rais.firms_raw ;
	set firms_95
		firms_96 
		firms_97
		firms_98 
		firms_99
		firms_00
		firms_01
		firms_02
		firms_03
		firms_04
		firms_05 
		firms_06 ;
run ;

proc sort data = rais.firms_raw ; by cnpj ; run ;


data rais.firms_raw ;
	merge rais.firms_raw (in = a) cnpj_cnae9406 ;
	by cnpj ;
	if a ;
run ;


proc sort data = rais.firms_raw ; by cnpj year ; run ;


proc delete data = firms_95 ; run ;
proc delete data = firms_96 ; run ;
proc delete data = firms_97 ; run ;
proc delete data = firms_98 ; run ;
proc delete data = firms_99 ; run ;
proc delete data = firms_00 ; run ;
proc delete data = firms_01 ; run ;
proc delete data = firms_02 ; run ;
proc delete data = firms_03 ; run ;
proc delete data = firms_04 ; run ;
proc delete data = firms_05 ; run ;
proc delete data = firms_06 ; run ;

proc delete data = cat_educ_95 ; run ;
proc delete data = cat_educ_96 ; run ;
proc delete data = cat_educ_97 ; run ;
proc delete data = cat_educ_98 ; run ;
proc delete data = cat_educ_99 ; run ;
proc delete data = cat_educ_00 ; run ;
proc delete data = cat_educ_01 ; run ;
proc delete data = cat_educ_02 ; run ;
proc delete data = cat_educ_03 ; run ;
proc delete data = cat_educ_04 ; run ;
proc delete data = cat_educ_05 ; run ;
proc delete data = cat_educ_06 ; run ;


proc delete data = total_emp_95 ; run ;
proc delete data = total_emp_96 ; run ;
proc delete data = total_emp_97 ; run ;
proc delete data = total_emp_98 ; run ;
proc delete data = total_emp_99 ; run ;
proc delete data = total_emp_00 ; run ;
proc delete data = total_emp_01 ; run ;
proc delete data = total_emp_02 ; run ;
proc delete data = total_emp_03 ; run ;
proc delete data = total_emp_04 ; run ;
proc delete data = total_emp_05 ; run ;
proc delete data = total_emp_06 ; run ;

proc delete data = cnpj_cnae9406 ; run ;





data inpc_min_wage (keep = year real_min_wage);
	set rais.inpc_min_wage ;
	if year >= 1995 & year <= 2006 ;
run ;



proc sort data = inpc_min_wage ; by year ; run ;

proc sort data = rais.firms_raw ; by year ; run ;


data rais.firms_raw ;
	merge  rais.firms_raw (in = a) inpc_min_wage ;
	by year ;
	if a ;
	avg_hourly_wage_reais    = avg_hourly_wage*real_min_wage ;
	median_hourly_wage_reais = median_hourly_wage*real_min_wage ;
	q1_hourly_wage_reais     = q1_hourly_wage*real_min_wage ;
	q3_hourly_wage_reais     = q3_hourly_wage*real_min_wage ;
run ;


proc sort data = rais.firms_raw ; by cnpj year ; run ;
