/*===========================================================================================*/
/*===========================================================================================*/
/*This SAS file imputes data on firms if they do not report in a given year.*/
/*For example, if a firm reports at RAIS in 1997 and 1999 but does not report in 1998,*/
/*Then we impute values for wages, skilled fraction and industry.*/
/*Imputed wages are given by an interpolation using lagged and lead values of employment.*/
/*===========================================================================================*/
/*===========================================================================================*/


/*================*/
/*Library Name*/
/*================*/

libname firms "C:\Users\Dix-Carneiro\Documents\Exchange Rates & Multi-Product Firms\Data" ;


data firms.firms (drop = avg_hourly_wage q1_hourly_wage median_hourly_wage q3_hourly_wage
                         avg_hourly_wage_reais q1_hourly_wage_reais median_hourly_wage_reais 
                         q3_hourly_wage_reais real_min_wage) ;
	set firms.firms_raw ;

	avg_wage    = avg_hourly_wage_reais ;
	q1_wage     =  q1_hourly_wage_reais ;
	median_wage =  median_hourly_wage_reais ;
	q3_wage     = q3_hourly_wage_reais ;

	fraction_skilled                = cat_educ3 + cat_educ4 ;

run ;

proc sort data = firms.firms ; by cnpj year ; run ;


/*==========================*/
/*Create Lagged Variables*/
/*==========================*/

data firms.firms ;
	set firms.firms ;
	
	lag_year               = lag(year) ;
	lag_wage               = lag(avg_wage) ;
	lag_q1_wage            = lag(q1_wage) ;
	lag_median_wage        = lag(median_wage) ;
	lag_q3_wage            = lag(q3_wage) ;
	lag_emp                = lag(total_emp) ;
	lag_cnae               = lag(cnae) ;
	lag_skilled            = lag(fraction_skilled) ;

run ;


proc sort data = firms.firms ; by cnpj year ; run ;


data firms.firms ;
	set firms.firms ;

	by cnpj ;

	if first.cnpj then 
	do ;
		lag_year        = . ;
		lag_wage        = . ;
		lag_q1_wage     = . ;
		lag_median_wage = . ;
		lag_q3_wage     = . ;
		lag_emp         = . ;
		lag_cnae        = . ;
		lag_skilled     = . ;
	end ;


run ;


/*===========================*/
/*Macro for the Imputation*/
/*===========================*/

%macro imputation ;


%do t = 1996 %to 2005 ;


data data&t. (drop = lag_year lag_wage lag_emp lag_cnae lag_q1_wage 
                     lag_q3_wage lag_median_wage lag_skilled);
	set firms.firms ;

	if lag_year ~= . and lag_year < &t and year > &t then do ;

		total_emp        = lag_emp         + ((&t - lag_year)/(year - lag_year))*(total_emp - lag_emp)            ;
		avg_wage         = lag_wage        + ((&t - lag_year)/(year - lag_year))*(avg_wage - lag_wage)            ;
		q1_wage          = lag_q1_wage     + ((&t - lag_year)/(year - lag_year))*(q1_wage - lag_q1_wage)          ;
		median_wage      = lag_median_wage + ((&t - lag_year)/(year - lag_year))*(median_wage - lag_median_wage)  ;
		q3_wage          = lag_q3_wage     + ((&t - lag_year)/(year - lag_year))*(q3_wage - lag_q3_wage)          ;
		cnae             = lag_cnae                                                                               ;
		fraction_skilled = lag_skilled     + ((&t - lag_year)/(year - lag_year))*(fraction_skilled - lag_skilled) ;

	end ;

	if lag_year ~= . and lag_year < &t and year > &t ;

	imputed = 1 ;

	year = &t ;

run ;

%end;

%mend;


%imputation ;



data firms.firms (drop = lag_year lag_wage lag_emp lag_cnae lag_q1_wage 
                         lag_q3_wage lag_median_wage lag_skilled) ;
	set data1996 data1997 data1998 data1999 data2000 data2001 data2002 
        data2003 data2004 data2005 firms.firms ;

	if imputed = . then imputed = 0 ;

run ;


proc sort data = firms.firms ; by cnpj year ; run ;


proc delete data = data1996 data1997 data1998 data1999 data2000 data2001 data2002 
        data2003 data2004 data2005 ; run ;


